import requests
import re
import os

#   定义一个变量用来保存下载图片的张数
i = 1

#  定义下载图片的方法
def downloadPic(url):
    global i  # 使用global声明这是一个全局变量,方法内无法直接使用全局变量
    html = requests.get(url).text
    pic_url = re.findall('"objURL":"(.*?)",', html, re.S)

    for each in pic_url:
        print("正在下载第" + str(i) + "张图片,图片地址:" + each)

        try:
            pic = requests.get(each, timeout=5)  # 可能有些图片存在网址打不开的情况,这里设置一个5秒的超时控制
        except Exception:  # 出现异常直接跳过
            print("【错误】当前图片无法下载")
            continue  # 跳过本次循环
        #  定义变量保存图片的路径
        string = './百度图片下载器/' + word + "/" + str(i) + ".jpg"
        fp = open(string, 'wb')
        fp.write(pic.content)
        fp.close()
        i += 1


if __name__ == '__main__':  # 主程序
    word = input("请输入您想要下载的图片:")

    #  先根据搜索的关键字判断存放该类别的文件夹是否存在,不存在则创建
    road = "./百度图片下载器/{}/".format(word)
    path = './百度图片下载器/'
    if not os.path.exists(road):
        if not os.path.exists(path):
            os.mkdir('./百度图片下载器/')
        os.mkdir(road)
    #  根据输入的内容构建url列表推导式【前21页内容】
    urls = [
        'http://image.baidu.com/search/flip?tn=baiduimage&ie=utf-8&word=' + word + '&ct=201326592&v=flip&pn={}'.format(
            str(i)) for i in range(0, 400, 20)]

    for url in urls:
        downloadPic(url)

    print("下载完成!")



import requests
import jsonpath
import os

def song_download(url,title,author):
    # 创建文件夹
    os.makedirs("music",exist_ok=True)
    path = 'music\{}.mp3'.format(title)
    print('歌曲:{0}-{1},正在下载...'.format(title,author))
    # 下载（这种读写文件的下载方式适合少量文件的下载）
    content = requests.get(url).content
    with open(file = title + author + '.mp3',mode='wb') as f:
      f.write(content)
    print('下载完毕,{0}-{1},请试听'.format(title,author))
class md:
  """
    1.url
    2.模拟浏览器请求
    3.解析网页源代码
    4.保存数据
      """
  def get_music_name(name, platfrom, index):
    """
    搜索歌曲名称
    :return:
    """
    #print("1.网易云:netease\n2.QQ:qq\n3.酷狗:kugou\n4.酷我:kuwo\n5.百度:baidu\n6.喜马拉雅:ximalaya")
    #print("-------------------------------------------------------")
    url = 'https://music.liuzhijin.cn/'
    headers = {
      "user-agent":"Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/87.0.4280.141 Safari/537.36",
      # 判断请求是异步还是同步
      "x-requested-with":"XMLHttpRequest",
    }
    param = {
      "input":name,
      "filter":"name",
      "type":platfrom,
      "page": 1,
    }
    res = requests.post(url=url,data=param,headers=headers)
    json_text = res.json()

    title = jsonpath.jsonpath(json_text,'$..title')
    author = jsonpath.jsonpath(json_text,'$..author')
    url = jsonpath.jsonpath(json_text, '$..url')
    if title:
      songs = list(zip(title,author,url))
      for s in songs:
        print(s[0],s[1],s[2])
      song_download(url[index],title[index],author[index])
    else:
      raise '没有搜索结果！'



from setuptools import setup, find_packages

setup(
	name = 'Xiaoimage',
	version = '2.1.5',
	packages = find_packages(),
	include_package_data = True,
        scripts=['./python-exe可执行程序/load-image.py', './python-exe可执行程序/baidu-image.py'],
	install_requires=[
		'Flask',
                'requests',
                'BeautifulSoup4',
	],
        entry_points="""
            [consle_scripts]
            xiaoimage = Xiaoimage:main
        """,
)
